==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/ToolChain/install_19_FixPointLib.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="400_fix_point_lib"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

if [ ! -e OK.Docs ]; then #{

  dir ../../Documentation/Math/
  #X echo "ll `pwd`/../../Documentation/Math/"
  Get_Fails=""
  getFile http://www.isep.pw.edu.pl/ZakladNapedu/lab-skp/ IQmath.pdf   FixPointLib_IQMath_Manual.pdf    ../../Documentation/Math/
  getFile http://code.google.com/p/                       fixpointlib  FixPointLib_IQMath_Overview.html ../../Documentation/Math/
  if [ "$Get_Fails" == "" ]; then
    touch OK.Docs
  else
    echo "$0 - ERROR: missing files: $Get_Fails"
  fi
fi #}
if [ ! -e OK.Install ]; then #{
  echo "installing in $INSTALLPATH ..."
  InstallDir=`pwd`
  
  InstallInHomeDir="1"
  if [ "$InstallInHomeDir" == "1" ]; then
    Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
  else
    findPrefix    # install for all users
  fi
  
  if [ ! -e OK.Packages ]; then #{
    installPackage svn
    installPackage subversion
    touch OK.Packages
  fi #}
  
  
  svn checkout http://fixpointlib.googlecode.com/svn/trunk/ fixpointlib-read-only
  
  Folder="fixpointlib-read-only/CortexM3/Project/FixPointLibTest/uVisionGcc"
  if [ -d ${Folder} ]; then
    cp -R $Folder .
    add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/fixpointlib-read-only"
    if [ -e IQmath.pdf ]; then
      rm 2>/dev/null uVisionGcc/IQmath.pdf
      ln IQmath.pdf uVisionGcc/
    fi
  fi
  
  if [ -d uVisionGcc ]; then
    echo "" >OK.Install
  fi
  #cd ..
fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  Name="${INSTALLPATH}"
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name

INCLUDE_DIRS += -I additionals/$Name/
LD_LIBS += additionals/$Name/FixPointLib.lib

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Fixpoint Library (faster calculations than software floating point)"
  
  # create links into extensions.active/
  echo "createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET" >>$File
  
  createActivateScriptTail $File $Name
  #}

  addLine ../scripts/createLinks.sh "rm 2>/dev/null $INSTALLPATH;  ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/uVisionGcc/  $INSTALLPATH"
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/ToolChain/install_19_FixPointLib.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="400_fix_point_lib"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

if [ ! -e OK.Docs ]; then #{

  dir ../../Documentation/Math/
  #X echo "ll `pwd`/../../Documentation/Math/"
  Get_Fails=""
  getFile http://www.isep.pw.edu.pl/ZakladNapedu/lab-skp/ IQmath.pdf   FixPointLib_IQMath_Manual.pdf    ../../Documentation/Math/
  getFile http://code.google.com/p/                       fixpointlib  FixPointLib_IQMath_Overview.html ../../Documentation/Math/
  if [ "$Get_Fails" == "" ]; then
    touch OK.Docs
  else
    echo "$0 - ERROR: missing files: $Get_Fails"
  fi
fi #}
if [ ! -e OK.Install ]; then #{
  echo "installing in $INSTALLPATH ..."
  InstallDir=`pwd`
  
  InstallInHomeDir="1"
  if [ "$InstallInHomeDir" == "1" ]; then
    Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
  else
    findPrefix    # install for all users
  fi
  
  if [ ! -e OK.Packages ]; then #{
    installPackage svn
    installPackage subversion
    touch OK.Packages
  fi #}
  
  
  svn checkout http://fixpointlib.googlecode.com/svn/trunk/ fixpointlib-read-only
  
  Folder="fixpointlib-read-only/CortexM3/Project/FixPointLibTest/uVisionGcc"
  if [ -d ${Folder} ]; then
    cp -R $Folder .
    add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/fixpointlib-read-only"
    if [ -e IQmath.pdf ]; then
      rm 2>/dev/null uVisionGcc/IQmath.pdf
      ln IQmath.pdf uVisionGcc/
    fi
  fi
  
  if [ -d uVisionGcc ]; then
    echo "" >OK.Install
  fi
  #cd ..
fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  Name="${INSTALLPATH}"
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

INCLUDE_DIRS += -I additionals/$Name/
LD_LIBS += additionals/$Name/FixPointLib.lib

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Fixpoint Library (faster calculations than software floating point)"
  
  # create links into extensions.active/
  echo "createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET" >>$File
  
  createActivateScriptTail $File $Name
  #}

  addLine ../scripts/createLinks.sh "rm 2>/dev/null $INSTALLPATH;  ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/uVisionGcc/  $INSTALLPATH"
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
